@@ -1,13 +1,13 @@
-use strict;
-use warnings;
 package Proch::Cmd;
+use 5.012;
+use warnings;
+$Proch::Cmd::VERSION = 0.005;
 
-$Proch::Cmd::VERSION = 0.0041;
-# ABSTRACT: Execute shell commands controlling inputs and outputs
+# ABSTRACT: Execute shell commands with caching capability to store output of executed programs (useful for multi step pipelines where some steps can take long) {beta}
 
 
 use 5.014;
-use Moose; 
+use Moose;
 use Data::Dumper;
 use Digest::MD5;
 use Storable qw(lock_store lock_nstore lock_retrieve);
@@ -28,8 +28,8 @@ has no_cache     => ( is => 'rw', isa => 'Bool');
 has save_stderr  => ( is => 'rw' );
 
 has command => (
-    is => 'rw',  
-    required => 1, 
+    is => 'rw',
+    required => 1,
     isa => 'Str',
 );
 
@@ -56,7 +56,7 @@ has output_files => (
 
 has cache_file => (
 	is => 'ro',
-	isa => 'Str', 
+	isa => 'Str',
 );
 
 
@@ -67,7 +67,7 @@ has working_dir => (
 	default => '/tmp/',
 	#builder => '_readdefault_working_dir',
 );
- 
+
 sub _readdefault_working_dir {
 	my ($self) = @_;
 	say Dumper $self;
@@ -80,13 +80,13 @@ sub _check_input_files_exist {
 	my @msg = ();
 	my $errors = 0;
 	my $output;
-	
+
 	# Check input input_files
 	foreach my $file (@{ $self->{input_files} }) {
 		if (! -s "$file") {
 			$errors++;
 			push(@msg, qq("$file") );
-		} 
+		}
 	}
 
 	$output->{errors} = $errors;
@@ -99,19 +99,20 @@ sub _check_input_files_exist {
 		return $output;
 	}
 }
+
 sub _check_output_files_exist {
 	# All {input_files} need to be found
 	my ($self) = @_;
 	my @msg = ();
 	my $errors = 0;
 	my $output;
-	
+
 	# Check input input_files
 	foreach my $file (@{ $self->{output_files} }) {
 		if (! -s "$file") {
 			$errors++;
 			push(@msg, qq("$file") );
-		} 
+		}
 	}
 
 	$output->{errors} = $errors;
@@ -138,7 +139,6 @@ sub simplerun {
 	my ($cache, $cache_file) = _get_cache($self);
 	if (! $self->{no_cache} and defined $cache) {
 		return $cache;
-		confess();
 	}
 	my $stderr_file = "$cache_file.stderr";
 	if (defined $self->{save_stderr} and $self->{save_stderr} ne "1") {
@@ -147,7 +147,7 @@ sub simplerun {
 
 	# Check input files
 	my $check_input = $self->_check_input_files_exist;
-	
+
 	# COMMAND EXECUTION
 	my $cmd = $self->command;
 	$cmd .= qq( 2> "$stderr_file") if (defined $self->{save_stderr});
@@ -167,7 +167,7 @@ sub simplerun {
 
 	# Save cache
 	_save_cache($self, $output) if (!$self->{no_cache});
-	
+
 	if ($self->{die_on_error} and ! $output->{success}) {
 		confess($output->{message})
 	} else {
@@ -175,10 +175,10 @@ sub simplerun {
 		return $output;
 	}
 
-} 
+}
 sub _error_header {
 	my ($command_string) = @_;
-	 
+
 	return "<Error when executing command '$command_string'>\n";
 }
 
@@ -193,7 +193,7 @@ sub _md5 {
  }
  close($fh);
  return $checksum->hexdigest;
- 
+
 }
 
 
@@ -201,7 +201,7 @@ sub _md5 {
 
 sub _get_cache {
 	my ($self) = @_;
- 
+
 	my $md5 = Digest::MD5->new;
 	my $WD = defined $self->{working_dir} ? $self->{working_dir} : $GLOBAL{'working_dir'};
 
@@ -275,11 +275,11 @@ __END__
 
 =head1 NAME
 
-Proch::Cmd - Execute shell commands controlling inputs and outputs
+Proch::Cmd - Execute shell commands with caching capability to store output of executed programs (useful for multi step pipelines where some steps can take long) {beta}
 
 =head1 VERSION
 
-version 0.0041
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -312,11 +312,11 @@ version 0.0041
 
 =head1 NAME
 
-Proch::Cmd - a simple library to execute shell commands
+Proch::Cmd - Execute shell commands controlling inputs and outputs
 
 =head1 VERSION
 
-version 0.004
+version 0.0041
 
 =head1 METHODS
 
@@ -332,7 +332,7 @@ The shell command to execute
 
 =item I<workingdir> (default: /tmp) [important]
 
-Command temporary directory, should be the pipeline output directory, can be 
+Command temporary directory, should be the pipeline output directory, can be
 omitted for minor commands like 'mkdir', but should be set for pipeline steps.
 
 =item I<description>
@@ -363,11 +363,19 @@ Don't skip command execution if the command was already executed
 
 =head2 simplerun()
 
-Executes the shell command returning an object
+Executes the shell command returning an object.
+
+=head2 get_global('Attribute')
+
+Returns the value of a setting given its name ('Attribute')
+
+=head2 set_global('Attribute', 'Value')
+
+Set the value of a setting item, given its name ('Attribute')
 
 =head1 ACCESSORY SCRIPTS
 
-The 'scripts' directory contain a I<read_cache_files.pl> that can be used to display the 
+The 'scripts' directory contain a I<read_cache_files.pl> that can be used to display the
 content of this module's cache files. The 'data' directory contain a valid example of data
 file called 'data.ok'. To view its content:
 
@@ -375,14 +383,6 @@ file called 'data.ok'. To view its content:
 
 =head1 AUTHOR
 
-Andrea Telatin <andrea@telatin.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is free software under MIT Licence.
-
-=head1 AUTHOR
-
 Andrea Telatin <andrea.telatin@quadram.ac.uk>
 
 =head1 COPYRIGHT AND LICENSE
